# Table of Contents

- [getting-started-building-your-it-component-inventory](<./getting-started-building-your-it-component-inventory.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Getting Started: Building Your IT Component Inventory](<./Getting-Started-Building-Your-IT-Component-Inventory.md>)
  - [Overview](<./Getting-Started-Building-Your-IT-Component-Inventory/Overview.md>)
  - [Building Your IT Component Inventory](<./Getting-Started-Building-Your-IT-Component-Inventory/Building-Your-IT-Component-Inventory.md>)
  - [Creating IT Component Fact Sheets Manually](<./Getting-Started-Building-Your-IT-Component-Inventory/Creating-IT-Component-Fact-Sheets-Manually.md>)
  - [Importing IT Components Using an Excel File](<./Getting-Started-Building-Your-IT-Component-Inventory/Importing-IT-Components-Using-an-Excel-File.md>)
  - [Importing IT Components Using Inventory Builder](<./Getting-Started-Building-Your-IT-Component-Inventory/Importing-IT-Components-Using-Inventory-Builder.md>)
  - [Importing IT Components Using SAP Discovery Feature](<./Getting-Started-Building-Your-IT-Component-Inventory/Importing-IT-Components-Using-SAP-Discovery-Feature.md>)
  - [Importing IT Components Using Self-Built Software Discovery Feature](<./Getting-Started-Building-Your-IT-Component-Inventory/Importing-IT-Components-Using-Self-Built-Software-Discovery-Feature.md>)
  - [Importing IT Components Through ServiceNow Integration](<./Getting-Started-Building-Your-IT-Component-Inventory/Importing-IT-Components-Through-ServiceNow-Integration.md>)
  - [Building a Complete Picture of Dependencies via SaaS Discovery](<./Getting-Started-Building-Your-IT-Component-Inventory/Building-a-Complete-Picture-of-Dependencies-via-SaaS-Discovery.md>)
  - [Avoiding Duplicates When Importing IT Components](<./Getting-Started-Building-Your-IT-Component-Inventory/Avoiding-Duplicates-When-Importing-IT-Components.md>)
  - [Enriching IT Component Details from the Reference Catalog](<./Getting-Started-Building-Your-IT-Component-Inventory/Enriching-IT-Component-Details-from-the-Reference-Catalog.md>)
  - [Related Resources](<./Getting-Started-Building-Your-IT-Component-Inventory/Related-Resources.md>)
  - [Was this page helpful?](<./Getting-Started-Building-Your-IT-Component-Inventory/Was-this-page-helpful.md>)
